==> larus_board-1.1.0.zip: larus_board-1.1.0/lb_private/lang/en/ucp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_activated'=>'Account activated',
'auto_bookmark'=>'Automatic Bookmarking',
'blacklist_has_been_added'=>'You have blacklisted this user and ignore all his postings.',
'blacklist_has_been_removed'=>'You removed this user from blacklisting and all his postings will be visible again.',
'bookmark_has_been_added'=>'A bookmark to this posting has been added.',
'bookmark_has_been_removed'=>'A bookmark has been removed from this posting.',
'change_password'=>'Change password',
'comment'=>'User comment',
'currently_no_bookmarks'=>'You have no bookmarks stored at the moment...',
'default_post_license'=>'Default License of your Postings',
'delete_user_confirm'=>'I do really want to delete this user!',
'delete_user_keep_posts'=>'Keep postings of this user',
'explain_account_active'=>'If the account is disabled, the user cannot login. This can be used to enforce a ban from the forum due to service abusing/rule violations.',
'explain_approvement'=>'Should new postings immediately be approved? Use "default" to keep the setting inherited by user group.',
'explain_auto_bookmark'=>'If <u>enabled</u> any new topic you submit will automatically added to your bookmarks.',
'explain_comment'=>'Any comment you set here, will shown to him on next login and removed after his logout.',
'explain_group'=>'Select the user group this user belongs to.',
'explain_login_annoy'=>'If you want to do some fun while this user is logged in, enable some annoyances. Can be useful to drive away nasty people. If enabled, something like showing a blank page, random error messages, logging out or making a kaleidoscope will happen sporadically.',
'explain_login_liberal'=>'If you are told your IP-Address is changing often during login, you can disable this restriction here. Please be careful when <u>enabling</u> "soft login". Usually this is required behind a proxy server or when connecting through anonymizer networks.',
'explain_password'=>'Please use a password containing a variety of characters. Do not use words easy to guess (like your kid s name or birth date) or from a dictionary, even no variations like adding a number or spell it backwards. A good strategy is to use a sentence you remember well and take the first letter of any word. In example use "My Dad showed me the 9 planets last night" and you password would be "MDsmt9pln" then. Finally the password must at least five characters in length with a maximum of thirty-one (31).',
'explain_post_license'=>'You can select the license applied to any of your future postings. Older keep their without change.',
'explain_style'=>'You can set the look and feel of our forum here to any layout and language you would like to. Leave "--" for default.',
'explain_timezone'=>'If you want to make your time shown correctly, please provide your local timezone. Leave "--" for default.',
'explain_ucp_mail'=>'You should provide a valid e-mail address here, so we can inform you about any changes on our forum. There will be low traffic and your address is kept private. If you do not want that, please keep this field blank. Please note, you will not be able to use "Forgot Password" in the future.',
'explain_warning'=>'If this user violates the terms of use or is otherwise attracting interest by misbehaviour, you can raise his warning level here. When reaching higher levels this fact will be shown in public on his profile beside all of his postings. Additionally, on the highest level this user is informed after login until the level is reduced.',
'general_data'=>'General Data',
'last_postings_by_user'=>'Recent postings by user',
'login_annoy'=>'Annoy during login',
'login_liberal'=>'Soft login security',
'mail_has_no_mx_dns_record'=>'Your e-mail address seems not to have an assigned mail server!',
'mail_not_valid'=>'Your e-mail address is not valid!',
'must_not_edit_foreign_profile'=>'You must not edit a foreign profile due to lacking executive permission!',
'my_bookmarks'=>'My Bookmarks',
'my_profile_settings'=>'My profile settings',
'new_passwords_not_equal'=>'Your new passwords are not equal!',
'old_password_not_correct'=>'Your current password is not correct!',
'password_again'=>'Please repeat',
'password_new'=>'New password',
'password_old'=>'Current password',
'posting_already_reported'=>'This posting has already been reported by an user!',
'posting_approvement'=>'Posting approvement',
'posting_count'=>'Postings Submitted',
'posting_report_success'=>'Thank you for reporting this posting to us. We will investigate it.',
'post_license_msg_ccbynd'=>'Allow unrestricted distribution but no modification at all',
'post_license_msg_ccbysa'=>'Allow unrestricted distribution and adaption as long as the license is kept',
'post_license_msg_none'=>'No distribution except quoting in our forum',
'profile_successfully_saved'=>'This profile has been saved.',
'show_effective_permission'=>'Show effective permissions',
'show_my_last_activity'=>'Show my last postings',
'style'=>'Look and feel',
'timezone'=>'Timezone',
'time_format_24h'=>'Use 24-Hours format',
'visiting_card'=>'Visiting Card',
'warning_foreign_profile'=>'Please note you are editing a foreign profile!'
);
?>

==> larus_board-1.2.0.zip: larus_board-1.2.0/lb_private/lang/en/ucp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_activated'=>'Account activated',
'auto_bookmark'=>'Automatic Bookmarking',
'blacklist_has_been_added'=>'You have blacklisted this user and ignore all his postings.',
'blacklist_has_been_removed'=>'You removed this user from blacklisting and all his postings will be visible again.',
'bookmark_has_been_added'=>'A bookmark to this posting has been added.',
'bookmark_has_been_removed'=>'A bookmark has been removed from this posting.',
'change_password_later'=>'Change password after submitting profile',
'comment'=>'User comment',
'currently_no_bookmarks'=>'You have no bookmarks stored at the moment...',
'default_post_license'=>'Default License of your Postings',
'delete_user_confirm'=>'I do really want to delete this user!',
'delete_user_keep_posts'=>'Keep postings of this user',
'explain_account_active'=>'If the account is disabled, the user cannot login. This can be used to enforce a ban from the forum due to service abusing/rule violations.',
'explain_approvement'=>'Should new postings immediately be approved? Use "default" to keep the setting inherited by user group.',
'explain_auto_bookmark'=>'If <u>enabled</u> any new topic you submit will automatically added to your bookmarks.',
'explain_comment'=>'Any comment you set here, will shown to him on next login and removed after his logout.',
'explain_group'=>'Select the user group this user belongs to.',
'explain_login_annoy'=>'If you want to do some fun while this user is logged in, enable some annoyances. Can be useful to drive away nasty people. If enabled, something like showing a blank page, random error messages, logging out or making a kaleidoscope will happen sporadically.',
'explain_login_liberal'=>'If you are told your IP-Address is changing often during login, you can disable this restriction here. Please be careful when <u>enabling</u> "soft login". Usually this is required behind a proxy server or when connecting through anonymizer networks.',
'explain_post_license'=>'You can select the license applied to any of your future postings. Older keep their without change.',
'explain_style'=>'You can set the look and feel of our forum here to any layout and language you would like to. Leave "--" for default.',
'explain_timezone'=>'If you want to make your time shown correctly, please provide your local timezone. Leave "--" for default.',
'explain_ucp_mail'=>'You should provide a valid e-mail address here, so we can inform you about any changes on our forum. There will be low traffic and your address is kept private. If you do not want that, please keep this field blank. Please note, you will not be able to use "Forgot Password" in the future.',
'explain_warning'=>'If this user violates the terms of use or is otherwise attracting interest by misbehaviour, you can raise his warning level here. When reaching higher levels this fact will be shown in public on his profile beside all of his postings. Additionally, on the highest level this user is informed after login until the level is reduced.',
'general_data'=>'General Data',
'last_postings_by_user'=>'Recent postings by user',
'login_annoy'=>'Annoy during login',
'login_liberal'=>'Soft login security',
'mail_has_no_mx_dns_record'=>'Your e-mail address seems not to have an assigned mail server!',
'must_not_edit_foreign_profile'=>'You must not edit a foreign profile due to lacking executive permission!',
'my_bookmarks'=>'My Bookmarks',
'my_profile_settings'=>'My profile settings',
'posting_already_reported'=>'This posting has already been reported by an user!',
'posting_approvement'=>'Posting approvement',
'posting_count'=>'Postings Submitted',
'posting_report_success'=>'Thank you for reporting this posting to us. We will investigate it.',
'post_license_msg_ccbynd'=>'Allow unrestricted distribution but no modification at all',
'post_license_msg_ccbysa'=>'Allow unrestricted distribution and adaption as long as the license is kept',
'post_license_msg_none'=>'No distribution except quoting in our forum',
'profile_successfully_saved'=>'This profile has been saved.',
'show_effective_permission'=>'Show effective permissions',
'show_my_last_activity'=>'Show my last postings',
'style'=>'Look and feel',
'timezone'=>'Timezone',
'time_format_24h'=>'Use 24-Hours format',
'visiting_card'=>'Visiting Card',
'warning_foreign_profile'=>'Please note you are editing a foreign profile!'
);
?>
